@@ -22,13 +22,12 @@ from plib.ui.output import PTextOutput
 from plib.ui.socket import PSocketTransport
 from plib.ui.widgets import *
 
-try:
-    import pyidserver3 as pyidserver
-except ImportError:
+
+def _load_example_module():
     from plib.stdlib.imp import import_from_path
     from plib.stdlib.postinstall import get_share_dir
     
-    pyidserver = import_from_path(
+    return import_from_path(
         os.path.join(
             get_share_dir('plib3.stdlib', 'plib.stdlib'),
             'examples', 'pyidserver'
@@ -37,6 +36,9 @@ except ImportError:
     )
 
 
+pyidserver = _load_example_module()
+
+
 PROTOCOL_MAP = {proto: items[0] for proto, items in pyidserver.protocols.items()}
 
 DEFAULT_DNSONLY = pyidserver.run_main.__defaults__[2]
