@@ -578,11 +578,19 @@ class PWxFileDialog(PFileDialogBase):
         dlg.Destroy()
         return retval
     
-    def open_filename(self, path, filter):
+    def _translate_filter_item(self, caption, ext_str):
+        return "{0} ({1})|{1}".format(caption, ext_str)
+    
+    ext_sep = ";"
+    filter_sep = "|"
+    
+    def _open_filename(self, path, filter, selected_filter):
+        # TODO: how to use selected_filter?
         return self.wx_filedialog("Select file to open", path, filter,
                                   wx.FD_OPEN)
     
-    def save_filename(self, path, filter):
+    def _save_filename(self, path, filter, selected_filter):
+        # TODO: how to use selected_filter?
         return self.wx_filedialog("Select file to save", path, filter,
                                   wx.FD_SAVE)
 
